@@ -338,6 +338,41 @@ mediaShow.getContentListing = function (slideshow)
     });
 }
 
+Arnolfini.portletLinks = function ()
+{
+	$('.portletStaticText ul li a').not("#FooterPortletManager .portletStaticText ul li a").each(function()
+		{
+			var elem = $(this);
+			var URL = $(this).attr("href") + '/get_number_of_results';
+			
+			$.getJSON(URL, function(data)
+				  {
+					if (data != null)
+					{
+						var count = $('<span class="resultCount"> '+data+'</span>')
+						elem.after(count);
+						if (data == 0)
+						{
+							elem.hide();
+						}
+					}
+				  });
+		});
+};
+
+/*   resizer handler */
+resizer.onResize = function ()
+{
+	if (resizer.currentMode == "small" || resizer.currentMode == "mobile")
+	{
+		$('#portal-column-one').masonry({columnWidth:189, gutterWidth:69, itemSelector:'.portletWrapper', isResizable:true, animate:false});
+	}
+	else
+	{
+		$('#portal-column-one').masonry( 'destroy' );
+	}
+}
+
 $(document).ready(function() {
 	Arnolfini.events();
 	Arnolfini.archiveShowButtons();
@@ -345,16 +380,18 @@ $(document).ready(function() {
 	{
 		 var currentLetter= "";
 		 $('.separateByLetters').find('h2.summary a').each(function ()
-								{
-									var name = $(this).text();
-									firstLetter = name[0].toUpperCase();
-									if (firstLetter != currentLetter)
-									{
-										currentLetter = firstLetter;
-										$(this).parent().prepend($('<a class="letter dontend" name="'+firstLetter+'">'+firstLetter+'</a>'));
-									}
-								});
+				{
+					var name = $(this).text();
+					firstLetter = name[0].toUpperCase();
+					if (firstLetter != currentLetter)
+					{
+						currentLetter = firstLetter;
+						$(this).parent().prepend($('<a class="letter dontend" name="'+firstLetter+'">'+firstLetter+'</a>'));
+					}
+				});
 		 $('.columns').columnize({ width:300 });
 	}
+	
+	Arnolfini.portletLinks();
 });
 
