@@ -13,6 +13,7 @@ from plone.app.querystring import queryparser
 from collective.media.interfaces import ICanContainMedia
 import re
 import time
+import json
 
 try:
     from Products.PloneGetPaid.interfaces import IBuyableMarker
@@ -193,8 +194,8 @@ class CommonBrowserView(BrowserView):
         
         dates = "%s"%(samedate and (event.start() is not None and event.start().strftime('%A, %d %B %Y') or event.end().strftime('%A, %d %B %Y')) or "%s to %s"%(event.start().strftime('%A, %d %B %Y'), event.end().strftime('%A, %d %B %Y')))
         
-        openingHour = event.start().strftime('%H:%M')
-        closingHour = event.end().strftime('%H:%M')
+        openingHour = event.start() is None and event.start().strftime('%H:%M') or "00:00"
+        closingHour = event.end() is not None and event.end().strftime('%H:%M') or "00:00"
         hoursExist = openingHour != closingHour
         
         hours = hoursExist and ', <span class="hours">%s to %s</span>'%(openingHour, closingHour) or ''
@@ -418,6 +419,35 @@ class SearchView(CommonBrowserView, Search):
     """
     Adding to Search view
     """
+    
+class NumberOfResults(CommonBrowserView):
+    """
+    Called by AJAX to know how many results in the collection. Returns JSON.
+    """
+    def getJSON(self):
+        callback = hasattr(self.request, 'callback') and 'json' + self.request['callback'] or None
+        only_documented = not hasattr(self.request, 'only_documented') 
+        
+        result = None
+        
+        if self.context.portal_type == 'Collection':
+            brains = self.context.queryCatalog(batch=False)
+            if only_documented:
+                result = []
+                for res in brains:
+                    if res.hasMedia:
+                        result.append(res)
+    
+        if result is not None:
+            jsonStr = json.dumps(len(result))
+        else:
+            jsonStr = json.dumps(result)
+            
+        if callback is not None:
+            return callback +'(' + jsonStr + ')'
+        else:
+            return jsonStr 
+
 
 class BlogView(FolderListing):
     """
